@@ -608,7 +608,7 @@ lnt_parse_uni <- function(lines,
                           exclude_lines,
                           verbose,
                           start_time,
-                          remove_cover = TRUE,
+                          remove_cover,
                           ...) {
   if (end_keyword == "auto") {
     end_keyword <- "^End of Document$"
@@ -620,7 +620,7 @@ lnt_parse_uni <- function(lines,
     length_keyword <- "^Length:\u00a0|^L\u00c4NGE:|^LONGUEUR:"
   }
   if (author_keyword == "auto") {
-    author_keyword <- "^Byline:\u00a0"
+    author_keyword <- "^Byline:\u00a0|^Author:\u00a0"
   }
   status("\t...files loaded", verbose, start_time)
   # exclude some lines
@@ -645,6 +645,10 @@ lnt_parse_uni <- function(lines,
   articles.l <- split(
     lines, cumsum(stringi::stri_detect_regex(lines, end_keyword))
   )
+  if (!length(articles.l)) {
+    stop("No articles found to parse.")
+  }
+  # last "article" only contains End of Document
   articles.l[[length(articles.l)]] <- NULL
   names(articles.l) <- NULL
   if (!length(articles.l)) {
@@ -659,17 +663,17 @@ lnt_parse_uni <- function(lines,
   }
   # split meta from body
   df.l <- lapply(articles.l, function(a) {
-    split <- which(stri_detect_regex(a, "^Body$"))[1]
+    split <- which(stringi::stri_detect_regex(a, "^Body$|^Text$"))[1]
     if (!is.na(split)) {
       list(
-        source = names(a)[1],
+        source = names(a)[2],
         meta = unname(a[2:split]),
         article = unname(a[(split + 1):(length(a) - 1)]),
         graphic = FALSE
       )
     } else {
       list(
-        source = names(a)[1],
+        source = names(a)[2],
         meta = NULL,
         article = a,
         graphic = TRUE
@@ -679,11 +683,11 @@ lnt_parse_uni <- function(lines,
   status("\t...articles split", verbose, start_time)
   # make data.frame
   ### length
-  . <- vapply(df.l, FUN.VALUE = character(1), function(i) {
+  len <- vapply(df.l, FUN.VALUE = character(1), function(i) {
     grep(pattern = length_keyword, x = i$meta,
          value = TRUE, ignore.case = TRUE)[1]
   })
-  length.v <- trimws(stri_replace_all_regex(., length_keyword, ""))
+  length.v <- trimws(stringi::stri_replace_all_regex(len, length_keyword, ""))
   status("\t...lengths extracted", verbose, start_time)
   ### headline First non emtpy line
   headline.v <- vapply(df.l, FUN.VALUE = character(1), function(i) {
@@ -720,7 +724,7 @@ lnt_parse_uni <- function(lines,
   author.v <- vapply(df.l, FUN.VALUE = character(1), function(i) {
     grep(pattern = author_keyword, x = i$meta, value = TRUE)[1]
   })
-  author.v <- stri_replace_all_regex(author.v, author_keyword, "")
+  author.v <- stringi::stri_replace_all_regex(author.v, author_keyword, "")
   author.v[author.v == ""] <- NA
   status("\t...authors extracted", verbose, start_time)
   ### section (where available)
@@ -728,7 +732,7 @@ lnt_parse_uni <- function(lines,
   section.v <- vapply(df.l, FUN.VALUE = character(1), function(i) {
     grep(pattern = section_keyword, x = i$meta, value = TRUE)[1]
   })
-  section.v <- stri_replace_all_regex(section.v, section_keyword, "")
+  section.v <- stringi::stri_replace_all_regex(section.v, section_keyword, "")
   status("\t...sections extracted", verbose, start_time)
   ### edition (not yet implemented)
   edition.v <- NA
@@ -1146,7 +1150,7 @@ lnt_similarity <- function(texts,
       stop("Supply either 'LNToutput' or 'texts' and 'dates'.")
     }
     if (is.null(IDs)) IDs <- seq_along(texts)
-  } else if (!missing(LNToutput)) {
+  } else {
     if (missing(texts)) texts <- LNToutput@articles$Article
     if (missing(dates)) dates <- LNToutput@meta$Date
     if (is.null(IDs)) IDs <- LNToutput@articles$ID
@@ -1339,6 +1343,7 @@ lnt_asDate <- function(x,
     Italian = "it",
     Russian = "ru"
   )
+  if (!format == "auto") formats <- format
   if (!locale == "auto") locales <- locale
   for (loc in locales) {
     dat <- stri_replace_all_regex(
